@@ -15,7 +15,7 @@ import GifTiffLoader as GTL
 import mahotas
 
 #from list_utils:
-from np_utils import deletecases,floatIntStringOrNone
+from np_utils import deletecases,floatIntStringOrNone,ziptranspose,shape_multiply
 
 #from MyPath import cprint
 #from pylab import *
@@ -241,12 +241,8 @@ def ConvertOutlinesToWatershed(origArr,outlines,useDilate=False,structure=[[0,1,
 
 
 def CheckForMalformedRegions(watershed,usePrint=True):
-    '''This goes through all frames and values and uses shapely to test if regions are disjoint in any way'''
-    
-    ### THIS FUNCTION IMPORTS SHAPELY DIRECTLY ... DO NOT LINK TO IT!
-    ### NO NEED TO ADD ANOTHER DEPENDENCY FOR EVERYONE ELSE!
-    #import shapely.geometry
-    # Actually, shapely is not needed for this operation after all (now uses polyArea)
+    '''This goes through all frames and values and uses a poylogon area
+       algorithm to test if regions are disjoint in any way.'''
     
     outputString = ''
     
@@ -263,12 +259,10 @@ def CheckForMalformedRegions(watershed,usePrint=True):
                 else:
                     filledRegion = (watershed[frame]==v).astype(np.int)
                 ic = ImageContour.GetContourInPlace(filledRegion,1)
-                #p=shapely.geometry.asPolygon(ic.tolist())
-                if filledRegion.sum() != polyArea(ic): #p.area:
+                if filledRegion.sum() != polyArea(ic):
                     s = ' '.join(['frame:',str(frame),', value:',str(v)])
                     outputString = outputString + ' ' + s + '\n'
-                #if not p.is_valid: # (temporarily?) removed
-                #    print 'frame:',frame,'value:',v,'--Value has regions connected by point only!'
+    
     if outputString=='':
         outputString = 'No malformed regions found!'
     
@@ -276,7 +270,18 @@ def CheckForMalformedRegions(watershed,usePrint=True):
         print outputString
     else:
         return outputString
+        
 
+def MakeCellNetworkJsonFiles(waterArr,d):
+    print 'Making static (simple networks) json file:'
+    ImageContour.SubContourTools.GetCellNetworkListStatic(waterArr,d,forceRemake=True)
+    print 'Made static json file!'
+    
+    print 'Making matched networks json file:'
+    _,_,allMatched = ImageContour.SubContourTools.GetMatchedCellNetworkListsPrevNext(waterArr,d,forceRemake=True)
+    print 'Made matched networks json file!'
+    
+    return allMatched
 
 def GetNeighborPairsByFrame(neighbors,woundVals): # pass Neighbors.neighbors
     neighborPairsByFrame = []
@@ -367,6 +372,19 @@ def GetNeighborValues(d,wv,ind):
     else:
         print 'Neighbors.py does not exist!'
 
+#####################################################################
+# Function for converting an outline array to a watershed array:
+#####################################################################
+def WatershedFillDoubleSizedOutlineArray(arr):
+    '''Take an image array similar to the "Outlines"
+       (but with lines=0, cells=1 instead)
+       and turn it into a (double-sized) fully segmented image'''
+    arrEdit = ndimage.measurements.label(arr)[0]
+    arrDouble = shape_multiply(arrEdit,[2,2]).astype(np.uint16)
+    arrInvDouble = (1-shape_multiply(arr,[2,2])).astype(np.uint16)
+    waterArr = mahotas.cwatershed(arrInvDouble,arrDouble)
+    return waterArr
+
 #####################################################################
 # Integrated intensity functions:
 #####################################################################
